from typing import TypeVar, Sequence, Callable

T = TypeVar('T')


def zero(v: T) -> T:
    return type(v)()


def for_each(s: Sequence, f: Callable[[...], None]):
    s = s.items() if isinstance(s, dict) else s
    if isinstance(s, dict):
        for x in s.items(): f(*x)
        return
    for x in s:
        x = next(iter(x.items())) if isinstance(x, dict) else x
        f(*x)



from typing import TypeVar

M = TypeVar("M", bound=dict)


def nonzero(m: M) -> M:
    return {k: v for k, v in m if v}


def diff(m1: M, m2: M, key=True) -> M:
    return {
        k: v for k, v in m1.items()
        if key and k not in m2 or v != m2.get(k, None)
    }


def diff_key(m1: M, m2: M) -> M:
    return [k for k, v in m1.items() if v != m2.get(k, None)]


def diff_value(m1: M, m2: M) -> M:
    return [v for k, v in m1.items() if v != m2.get(k, None)]



from typing import TypeVar

S = TypeVar("S", bound=list)
E = TypeVar("E")


def concat(*s: S | E) -> S:
    elems = []
    for x in s:
        if x is None:
            continue
        elems.extend(x) if isinstance(x, list) else elems.append(x)
    return elems


def insert(s: S, elem: E | S, i: int = None) -> S:
    i = len(s) if i is None else i
    s[i:i + 1] = elem if isinstance(elem, list) else [elem]
    return s
